@@ -6,6 +6,8 @@
     Generate HTML using python 3
 """
 
+__version__ = "0.0.3"
+
 from typing import *
 
 from .html import *
@@ -23,7 +25,7 @@ class domonic:
         return domonic.parse(r.text)
 
     @staticmethod
-    def print(domonic) -> str:
+    def print(domonic) -> str :
         ''' outputs HTML str '''
         # TODO - prettify by using newlines in returned content to save installing this?
         # from html5print import HTMLBeautifier
@@ -31,21 +33,27 @@ class domonic:
         pass
 
     @staticmethod
-    def parse(html:str):
+    def parse(html:str) -> str :
         ''' HTML as input and returns domonic '''
 
-        print("swallow honey!!!::::::::::::::::::::::::::::::")
+        print("attempting to parse the page")
 
+        # - TODO - should probs pretty it up first and strip want cant be
         # turn all tags into class definitions.
         # check closing tags. turn to closed bracks
         # create strings around content and remove white space
         # put underscores on attributes
 
         import re
+
+        html = ''.join(html.split('<!DOCTYPE HTML>'))
+        html = ''.join(html.split('<!doctype html>'))
         
         # html = "<html><body>some content</body></html>"
 
-        htmltags = ["html","header","head","body","meta","title","style","script","div","footer","img","a","p"]
+        # "style","script"
+
+        htmltags = ["html","span","button","link","form","nav","details","summary","header","head","body","meta","title","div","footer","img","a","p","h1","h2","h3","h4","h5","h6","hr","ul","ol","li","time","template","label","input","small","strong","option","select"]
 
         for tag in htmltags:
 
@@ -91,6 +99,25 @@ class domonic:
             # print(count, html)
         
         print(html)
+        
+
+        # close any tags that arent properly self closing
+        flag=False
+        for index,char in enumerate(html):
+            if char=="(":flag=True
+            if char==")":flag=False
+            if char==">" and flag is True:
+                html = f"{html[:index]},{html[index+1:]}" # replace it for a ','
+                # TODO - if its self closing. replace for a ')' instead
+
+        # strip any comments
+        cleaned=[]
+        for line in html.splitlines():
+            print('smelly fanny!')
+            if "<!" in line:
+                continue
+            cleaned.append(line)
+        html = '\n'.join(cleaned)
 
         # return eval('print("test")')
         # return eval('Location()')
